@@ -98,7 +98,7 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.nextquest.clicked.connect(self.choose_frage)
         self.ui.frageneinreichen.clicked.connect(self.fragen_einreichen)
         self.ui.newgame.clicked.connect(self.neuesspiel)
-        self.ui.exitgame.clicked.connect(self.closefunc)
+        self.ui.exitgame.clicked.connect(self.exit_save)
         self.ui.craveofrage.clicked.connect(self.send_email)
         self.ui.spielladen.clicked.connect(self.spielladen)
         self.ui.highscores.clicked.connect(self.highscores)
